@@ -411,6 +411,27 @@ class Smart(Generic[_T]):
 
         return self
 
+    @classmethod
+    def load_from(
+        cls,
+        source: Union['Smart', Mapping[str, Any], Sequence[str], Path],
+        name: Optional[str] = None,
+    ) -> Any:
+        """Loads object from the given source.
+
+        Args:
+            source: Smart object, dictionary, list or path of object to load.
+            name: Key of source dictionary.
+
+        Returns:
+            Instance of loaded source.
+
+        Raises:
+            TypeError if given source is not supported.
+
+        """
+        return cls().update_from(source=source, name=name).init()
+
     def init(
         self,
         name: Optional[str] = None,
