@@ -58,13 +58,27 @@ def flatten_keys(
 
 def check_key_is_in(
     key: str,
-    keys: Sequence[str],
+    dictionary: Dict[str, Any],
 ) -> bool:
-    key_parts = key.split(_KEY_SEPARATOR)
-    return any(all(k1 == k2 for k1, k2 in zip(key_parts, k.split(_KEY_SEPARATOR))) for k in keys)
+    key, _, sub_key = key.partition(_KEY_SEPARATOR)
+    if key not in dictionary:
+        return False
+
+    if not sub_key:
+        return True
+
+    dictionary = dictionary[key]
+
+    if not isinstance(dictionary, dict):
+        return True
+
+    return check_key_is_in(
+        key=sub_key,
+        dictionary=dictionary,
+    )
 
 
-def check_key_is_in_bidict(
+def remove_duplicated_key_and_value(
     key: str,
     key_dict: Dict[str, str],
     value_dict: Dict[str, str],
